function ts = testcollect(files,recursive)
  % TESTCOLLECT  Collects tests in a set of testset from files
  %
  %  This function allows to create a complex test set from files and
  % directories. The structure of the test set is defined from the directory
  % arganization and from the filenames organization.
  %
  %  Params
  %  ------
  % IN:
  %  files        =  A string related to an m file, or to a directory, or a
  %                 cell containing strings. (def=pwd)
  %  recursive    =  True to introspect recursively listed directories
  %                 (def=true)
  
  % Check for params:
  if nargin<1 files=pwd; end
  if nargin<2 recursive=true; end
  
  % Get the name:
  if isa(files,'char')
    [path,name,ext] = fileparts(files);
  else
    name = 'Main';
  end
  
  % The testset can be created with a single call:
  ts = CollectTests(files,recursive,name);
end

% ------------------------ LOCAL FUNCTIONS ------------------------

% Collects tests from a cell of strings:
% function ts = CollectTests(files,recursive,name)
%   disp(name);
%   % Check if the set of files is reduced to a single filename:
%   if isa(files,'char')
%       ts = CollectTests({},recursive,name);
%   elseif isa(files,'cell')
%     % Iteratively collects in a new testset:
%     
%     tests = cell(1,numel(files));
%     for ind=1:numel(files)
%       % A single testset is created:
%       tests{ind} = CollectTests(files{ind},recursive, ...
%         sprintf('%s%3.3d',name,ind));
%     end
%     % Now a testset can be generated:
%     if(isempty(tests))
%       disp('  is empty');
%       disp(tests);
%       disp(name);
%       keyboard;
%       ts = testset(name,name,tests);
%     else
%       disp('  normal');
%       ts = testset(name,name,tests);
%     end
%   else
%     % Cannot be of other types!
%     error('Cell or filename required for testset collectioning!');
%   end
% end
% -----------------------------------------------------------------

% Inspect a directory:
function ts = CollectFromDir(dirname,recursive)
  
  % Obtain filenames in the directory:
  files = dirfiles(dirname);
  %   disp(files);
  
  % Iterating on files and generating the filenames cell:
  c = {};
  for ind=1:size(files,2)
    % Skipping bad files:
    [path,name,ext] = fileparts(files{ind});
    if strcmp([name,ext],'.') || strcmp([name,ext],'..') || ...
        (not(recursive) && isdir(files{ind})) || ...
        not(isdir(files{ind}) || strcmpi(ext,'.m'))
      continue;
    end
    
    % Collecting:
    c = {c{:},files{ind}};
  end
  
  % All is collected... now the testset can be generated:
  [path,name,ext] = fileparts(dirname);
  ts = CollectTests(c,recursive,name);
end
